==> spring-1.2.4-sources.jar: org/springframework/core/enums/LabeledEnum.java <==
/*
 * Copyright 2002-2005 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.core.enums;

import java.util.Comparator;

import org.springframework.util.comparator.CompoundComparator;
import org.springframework.util.comparator.NullSafeComparator;

/**
 * A interface for objects that represent a labled enumeration.
 * Each such enum instance has the following characteristics:
 *
 * <ul>
 * <li>A type that identifies the enum's class.
 * For example: <code>com.mycompany.util.FileFormat</code>.
 *
 * <li>A code that uniquely identifies the enum within the context of its type.
 * For example: "CSV". Different classes of codes are possible
 * (Character, Integer, String).
 *
 * <li>A descriptive label. For example: "the CSV File Format".
 * </ul>
 *
 * @author Keith Donald
 * @since 1.2.2
 */
public interface LabeledEnum extends Comparable {

	/**
	 * Shared Comparator instance that sorts enumerations by <code>CODE_ORDER</code>.
	 */
	public static final Comparator CODE_ORDER = new Comparator() {

		public int compare(Object o1, Object o2) {
			Comparable c1 = ((LabeledEnum) o1).getCode();
			Comparable c2 = ((LabeledEnum) o2).getCode();
			return c1.compareTo(c2);
		}
	};

	/**
	 * Shared Comparator instance that sorts enumerations by <code>LABEL_ORDER</code>.
	 */
	public static final Comparator LABEL_ORDER = new Comparator() {

		public int compare(Object o1, Object o2) {
			LabeledEnum e1 = (LabeledEnum) o1;
			LabeledEnum e2 = (LabeledEnum) o2;
			Comparator comp = new NullSafeComparator(String.CASE_INSENSITIVE_ORDER, true);
			return comp.compare(e1.getLabel(), e2.getLabel());
		}
	};

	/**
	 * Shared Comparator instance that sorts enumerations by <code>LABEL_ORDER</code>,
	 * then <code>CODE_ORDER</code>.
	 */
	public static final Comparator DEFAULT_ORDER =
			new CompoundComparator(new Comparator[] { LABEL_ORDER, CODE_ORDER });


	/**
	 * Return this enumeration's type.
	 */
	public Class getType();

	/**
	 * Return this enumeration's code.
	 * Each code should be unique within enumeration's of the same type.
	 */
	public Comparable getCode();

	/**
	 * Return a descriptive, optional label.
	 */
	public String getLabel();

}

==> spring-1.2.6-sources.jar: org/springframework/core/enums/LabeledEnum.java <==
/*
 * Copyright 2002-2005 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.core.enums;

import java.io.Serializable;
import java.util.Comparator;

import org.springframework.util.comparator.CompoundComparator;
import org.springframework.util.comparator.NullSafeComparator;

/**
 * A interface for objects that represent a labled enumeration.
 * Each such enum instance has the following characteristics:
 *
 * <ul>
 * <li>A type that identifies the enum's class.
 * For example: <code>com.mycompany.util.FileFormat</code>.
 *
 * <li>A code that uniquely identifies the enum within the context of its type.
 * For example: "CSV". Different classes of codes are possible
 * (Character, Integer, String).
 *
 * <li>A descriptive label. For example: "the CSV File Format".
 * </ul>
 *
 * @author Keith Donald
 * @since 1.2.2
 */
public interface LabeledEnum extends Comparable, Serializable {

	/**
	 * Shared Comparator instance that sorts enumerations by <code>CODE_ORDER</code>.
	 */
	public static final Comparator CODE_ORDER = new Comparator() {

		public int compare(Object o1, Object o2) {
			Comparable c1 = ((LabeledEnum) o1).getCode();
			Comparable c2 = ((LabeledEnum) o2).getCode();
			return c1.compareTo(c2);
		}
	};

	/**
	 * Shared Comparator instance that sorts enumerations by <code>LABEL_ORDER</code>.
	 */
	public static final Comparator LABEL_ORDER = new Comparator() {

		public int compare(Object o1, Object o2) {
			LabeledEnum e1 = (LabeledEnum) o1;
			LabeledEnum e2 = (LabeledEnum) o2;
			Comparator comp = new NullSafeComparator(String.CASE_INSENSITIVE_ORDER, true);
			return comp.compare(e1.getLabel(), e2.getLabel());
		}
	};

	/**
	 * Shared Comparator instance that sorts enumerations by <code>LABEL_ORDER</code>,
	 * then <code>CODE_ORDER</code>.
	 */
	public static final Comparator DEFAULT_ORDER =
			new CompoundComparator(new Comparator[] { LABEL_ORDER, CODE_ORDER });


	/**
	 * Return this enumeration's type.
	 */
	public Class getType();

	/**
	 * Return this enumeration's code.
	 * Each code should be unique within enumeration's of the same type.
	 */
	public Comparable getCode();

	/**
	 * Return a descriptive, optional label.
	 */
	public String getLabel();

}
